/****************************************************************************
** Meta object code from reading C++ file 'game.h'
**
** Created by: The Qt Meta Object Compiler version 63 (Qt 4.8.7)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/kigo-17.04.3/src/game/game.h"
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'game.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 63
#error "This file was generated using the moc from 4.8.7. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
static const uint qt_meta_data_Kigo__Game[] = {

 // content:
       6,       // revision
       0,       // classname
       0,    0, // classinfo
      15,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
      10,       // signalCount

 // signals: signature, parameters, type, tag, flags
      12,   11,   11,   11, 0x05,
      31,   11,   11,   11, 0x05,
      46,   11,   11,   11, 0x05,
      68,   11,   11,   11, 0x05,
      85,   11,   11,   11, 0x05,
     108,   11,   11,   11, 0x05,
     140,   11,   11,   11, 0x05,
     169,   11,   11,   11, 0x05,
     183,   11,   11,   11, 0x05,
     204,   11,   11,   11, 0x05,

 // slots: signature, parameters, type, tag, flags
     225,   11,   11,   11, 0x0a,
     254,  242,  237,   11, 0x08,
     273,   11,  237,   11, 0x28,
     288,   11,   11,   11, 0x08,
     306,  300,   11,   11, 0x08,

       0        // eod
};

static const char qt_meta_stringdata_Kigo__Game[] = {
    "Kigo::Game\0\0boardInitialized()\0"
    "boardChanged()\0boardSizeChanged(int)\0"
    "resigned(Player)\0passMovePlayed(Player)\0"
    "consecutivePassMovesPlayed(int)\0"
    "currentPlayerChanged(Player)\0waiting(bool)\0"
    "canRedoChanged(bool)\0canUndoChanged(bool)\0"
    "gameSetup()\0bool\0nonBlocking\0"
    "waitResponse(bool)\0waitResponse()\0"
    "readyRead()\0index\0undoIndexChanged(int)\0"
};

void Kigo::Game::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        Q_ASSERT(staticMetaObject.cast(_o));
        Game *_t = static_cast<Game *>(_o);
        switch (_id) {
        case 0: _t->boardInitialized(); break;
        case 1: _t->boardChanged(); break;
        case 2: _t->boardSizeChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 3: _t->resigned((*reinterpret_cast< const Player(*)>(_a[1]))); break;
        case 4: _t->passMovePlayed((*reinterpret_cast< const Player(*)>(_a[1]))); break;
        case 5: _t->consecutivePassMovesPlayed((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 6: _t->currentPlayerChanged((*reinterpret_cast< const Player(*)>(_a[1]))); break;
        case 7: _t->waiting((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 8: _t->canRedoChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 9: _t->canUndoChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 10: _t->gameSetup(); break;
        case 11: { bool _r = _t->waitResponse((*reinterpret_cast< bool(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = _r; }  break;
        case 12: { bool _r = _t->waitResponse();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = _r; }  break;
        case 13: _t->readyRead(); break;
        case 14: _t->undoIndexChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObjectExtraData Kigo::Game::staticMetaObjectExtraData = {
    0,  qt_static_metacall 
};

const QMetaObject Kigo::Game::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_Kigo__Game,
      qt_meta_data_Kigo__Game, &staticMetaObjectExtraData }
};

#ifdef Q_NO_DATA_RELOCATION
const QMetaObject &Kigo::Game::getStaticMetaObject() { return staticMetaObject; }
#endif //Q_NO_DATA_RELOCATION

const QMetaObject *Kigo::Game::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->metaObject : &staticMetaObject;
}

void *Kigo::Game::qt_metacast(const char *_clname)
{
    if (!_clname) return 0;
    if (!strcmp(_clname, qt_meta_stringdata_Kigo__Game))
        return static_cast<void*>(const_cast< Game*>(this));
    return QObject::qt_metacast(_clname);
}

int Kigo::Game::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    return _id;
}

// SIGNAL 0
void Kigo::Game::boardInitialized()
{
    QMetaObject::activate(this, &staticMetaObject, 0, 0);
}

// SIGNAL 1
void Kigo::Game::boardChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, 0);
}

// SIGNAL 2
void Kigo::Game::boardSizeChanged(int _t1)
{
    void *_a[] = { 0, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void Kigo::Game::resigned(const Player & _t1)
{
    void *_a[] = { 0, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void Kigo::Game::passMovePlayed(const Player & _t1)
{
    void *_a[] = { 0, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void Kigo::Game::consecutivePassMovesPlayed(int _t1)
{
    void *_a[] = { 0, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void Kigo::Game::currentPlayerChanged(const Player & _t1)
{
    void *_a[] = { 0, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}

// SIGNAL 7
void Kigo::Game::waiting(bool _t1)
{
    void *_a[] = { 0, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 7, _a);
}

// SIGNAL 8
void Kigo::Game::canRedoChanged(bool _t1)
{
    void *_a[] = { 0, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 8, _a);
}

// SIGNAL 9
void Kigo::Game::canUndoChanged(bool _t1)
{
    void *_a[] = { 0, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 9, _a);
}
QT_END_MOC_NAMESPACE
