#include <kdialog.h>
#include <klocale.h>

/********************************************************************************
** Form generated from reading UI file 'setupwidget.ui'
**
** Created by: Qt User Interface Compiler version 4.8.7
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SETUPWIDGET_H
#define UI_SETUPWIDGET_H

#include <QtCore/QVariant>
#include <QtGui/QAction>
#include <QtGui/QApplication>
#include <QtGui/QButtonGroup>
#include <QtGui/QCheckBox>
#include <QtGui/QDoubleSpinBox>
#include <QtGui/QFrame>
#include <QtGui/QGridLayout>
#include <QtGui/QHBoxLayout>
#include <QtGui/QHeaderView>
#include <QtGui/QLabel>
#include <QtGui/QRadioButton>
#include <QtGui/QSlider>
#include <QtGui/QSpacerItem>
#include <QtGui/QStackedWidget>
#include <QtGui/QVBoxLayout>
#include <QtGui/QWidget>
#include "klineedit.h"
#include "knuminput.h"
#include "kpushbutton.h"

QT_BEGIN_NAMESPACE

class Ui_SetupWidget
{
public:
    QVBoxLayout *verticalLayout_2;
    QStackedWidget *gameSetupStack;
    QWidget *newGamePage;
    QGridLayout *gridLayout_2;
    QLabel *label_12;
    QRadioButton *sizeSmall;
    QRadioButton *sizeMedium;
    QRadioButton *sizeBig;
    QHBoxLayout *horizontalLayout_4;
    QRadioButton *sizeOther;
    KIntSpinBox *sizeOtherSpinBox;
    QLabel *label_5;
    KIntSpinBox *handicapSpinBox;
    QLabel *label_4;
    QDoubleSpinBox *komiSpinBox;
    QSpacerItem *verticalSpacer_5;
    QWidget *loadGamePage;
    QVBoxLayout *verticalLayout_3;
    QFrame *frame_2;
    QGridLayout *gridLayout;
    QLabel *eventStaticLabel;
    QLabel *eventLabel;
    QLabel *locationStaticLabel;
    QLabel *locationLabel;
    QLabel *dateStaticLabel;
    QLabel *dateLabel;
    QLabel *roundStaticLabel;
    QLabel *roundLabel;
    QLabel *scoreStaticLabel;
    QLabel *scoreLabel;
    QLabel *komiStaticLabel;
    QLabel *komiLabel;
    QLabel *continueStaticLabel;
    QLabel *playerLabel;
    KIntSpinBox *startMoveSpinBox;
    QLabel *timeStaticLabel;
    QLabel *timeLabel;
    QSpacerItem *verticalSpacer_6;
    QSpacerItem *verticalSpacer_4;
    QGridLayout *gridLayout_4;
    QSpacerItem *horizontalSpacer_2;
    QCheckBox *whiteIsComputerCheckBox;
    QStackedWidget *whitePlayerStack;
    QWidget *whiteHumanPage;
    QHBoxLayout *horizontalLayout_2;
    QLabel *label_6;
    KLineEdit *whitePlayerName;
    QWidget *whiteComputerPage;
    QGridLayout *gridLayout_8;
    QLabel *label1;
    QLabel *label2;
    QSlider *whiteStrengthSlider;
    QSpacerItem *verticalSpacer_2;
    QLabel *blackStoneImageLabel;
    QCheckBox *blackIsComputerCheckBox;
    QStackedWidget *blackPlayerStack;
    QWidget *blackHumanPage;
    QHBoxLayout *horizontalLayout_3;
    QLabel *label_7;
    KLineEdit *blackPlayerName;
    QWidget *blackComputerPage;
    QGridLayout *gridLayout_3;
    QLabel *label2_3;
    QLabel *label1_3;
    QSlider *blackStrengthSlider;
    QSpacerItem *verticalSpacer_3;
    QSpacerItem *verticalSpacer_7;
    QSpacerItem *verticalSpacer_8;
    QSpacerItem *verticalSpacer_9;
    QLabel *whiteStoneImageLabel;
    QSpacerItem *verticalSpacer_10;
    QSpacerItem *verticalSpacer;
    QHBoxLayout *horizontalLayout;
    QSpacerItem *horizontalSpacer;
    KPushButton *startButton;

    void setupUi(QWidget *SetupWidget)
    {
        if (SetupWidget->objectName().isEmpty())
            SetupWidget->setObjectName(QString::fromUtf8("SetupWidget"));
        SetupWidget->resize(269, 510);
        verticalLayout_2 = new QVBoxLayout(SetupWidget);
        verticalLayout_2->setObjectName(QString::fromUtf8("verticalLayout_2"));
        gameSetupStack = new QStackedWidget(SetupWidget);
        gameSetupStack->setObjectName(QString::fromUtf8("gameSetupStack"));
        QSizePolicy sizePolicy(QSizePolicy::Preferred, QSizePolicy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(gameSetupStack->sizePolicy().hasHeightForWidth());
        gameSetupStack->setSizePolicy(sizePolicy);
        newGamePage = new QWidget();
        newGamePage->setObjectName(QString::fromUtf8("newGamePage"));
        gridLayout_2 = new QGridLayout(newGamePage);
        gridLayout_2->setObjectName(QString::fromUtf8("gridLayout_2"));
        label_12 = new QLabel(newGamePage);
        label_12->setObjectName(QString::fromUtf8("label_12"));

        gridLayout_2->addWidget(label_12, 0, 0, 1, 1);

        sizeSmall = new QRadioButton(newGamePage);
        sizeSmall->setObjectName(QString::fromUtf8("sizeSmall"));
        sizeSmall->setChecked(false);

        gridLayout_2->addWidget(sizeSmall, 1, 0, 1, 2);

        sizeMedium = new QRadioButton(newGamePage);
        sizeMedium->setObjectName(QString::fromUtf8("sizeMedium"));

        gridLayout_2->addWidget(sizeMedium, 2, 0, 1, 2);

        sizeBig = new QRadioButton(newGamePage);
        sizeBig->setObjectName(QString::fromUtf8("sizeBig"));
        sizeBig->setChecked(true);

        gridLayout_2->addWidget(sizeBig, 3, 0, 1, 2);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName(QString::fromUtf8("horizontalLayout_4"));
        sizeOther = new QRadioButton(newGamePage);
        sizeOther->setObjectName(QString::fromUtf8("sizeOther"));

        horizontalLayout_4->addWidget(sizeOther);

        sizeOtherSpinBox = new KIntSpinBox(newGamePage);
        sizeOtherSpinBox->setObjectName(QString::fromUtf8("sizeOtherSpinBox"));
        sizeOtherSpinBox->setEnabled(false);
        QSizePolicy sizePolicy1(QSizePolicy::MinimumExpanding, QSizePolicy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(sizeOtherSpinBox->sizePolicy().hasHeightForWidth());
        sizeOtherSpinBox->setSizePolicy(sizePolicy1);
        sizeOtherSpinBox->setMinimum(5);
        sizeOtherSpinBox->setMaximum(19);
        sizeOtherSpinBox->setValue(19);

        horizontalLayout_4->addWidget(sizeOtherSpinBox);


        gridLayout_2->addLayout(horizontalLayout_4, 4, 0, 1, 2);

        label_5 = new QLabel(newGamePage);
        label_5->setObjectName(QString::fromUtf8("label_5"));
        QSizePolicy sizePolicy2(QSizePolicy::Minimum, QSizePolicy::Preferred);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(label_5->sizePolicy().hasHeightForWidth());
        label_5->setSizePolicy(sizePolicy2);
        label_5->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_2->addWidget(label_5, 6, 0, 1, 1);

        handicapSpinBox = new KIntSpinBox(newGamePage);
        handicapSpinBox->setObjectName(QString::fromUtf8("handicapSpinBox"));
        handicapSpinBox->setEnabled(true);
        sizePolicy1.setHeightForWidth(handicapSpinBox->sizePolicy().hasHeightForWidth());
        handicapSpinBox->setSizePolicy(sizePolicy1);
        handicapSpinBox->setMinimum(1);
        handicapSpinBox->setMaximum(9);
        handicapSpinBox->setValue(4);

        gridLayout_2->addWidget(handicapSpinBox, 6, 1, 1, 1);

        label_4 = new QLabel(newGamePage);
        label_4->setObjectName(QString::fromUtf8("label_4"));
        sizePolicy2.setHeightForWidth(label_4->sizePolicy().hasHeightForWidth());
        label_4->setSizePolicy(sizePolicy2);
        label_4->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_2->addWidget(label_4, 7, 0, 1, 1);

        komiSpinBox = new QDoubleSpinBox(newGamePage);
        komiSpinBox->setObjectName(QString::fromUtf8("komiSpinBox"));
        sizePolicy1.setHeightForWidth(komiSpinBox->sizePolicy().hasHeightForWidth());
        komiSpinBox->setSizePolicy(sizePolicy1);
        komiSpinBox->setDecimals(1);
        komiSpinBox->setMaximum(50);
        komiSpinBox->setValue(4.5);

        gridLayout_2->addWidget(komiSpinBox, 7, 1, 1, 1);

        verticalSpacer_5 = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Minimum);

        gridLayout_2->addItem(verticalSpacer_5, 5, 0, 1, 1);

        gameSetupStack->addWidget(newGamePage);
        loadGamePage = new QWidget();
        loadGamePage->setObjectName(QString::fromUtf8("loadGamePage"));
        verticalLayout_3 = new QVBoxLayout(loadGamePage);
        verticalLayout_3->setContentsMargins(0, 0, 0, 0);
        verticalLayout_3->setObjectName(QString::fromUtf8("verticalLayout_3"));
        frame_2 = new QFrame(loadGamePage);
        frame_2->setObjectName(QString::fromUtf8("frame_2"));
        frame_2->setFrameShape(QFrame::NoFrame);
        frame_2->setFrameShadow(QFrame::Plain);
        gridLayout = new QGridLayout(frame_2);
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        eventStaticLabel = new QLabel(frame_2);
        eventStaticLabel->setObjectName(QString::fromUtf8("eventStaticLabel"));
        sizePolicy2.setHeightForWidth(eventStaticLabel->sizePolicy().hasHeightForWidth());
        eventStaticLabel->setSizePolicy(sizePolicy2);
        eventStaticLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(eventStaticLabel, 0, 0, 1, 1);

        eventLabel = new QLabel(frame_2);
        eventLabel->setObjectName(QString::fromUtf8("eventLabel"));
        sizePolicy2.setHeightForWidth(eventLabel->sizePolicy().hasHeightForWidth());
        eventLabel->setSizePolicy(sizePolicy2);
        eventLabel->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);
        eventLabel->setWordWrap(true);

        gridLayout->addWidget(eventLabel, 0, 1, 1, 1);

        locationStaticLabel = new QLabel(frame_2);
        locationStaticLabel->setObjectName(QString::fromUtf8("locationStaticLabel"));
        sizePolicy2.setHeightForWidth(locationStaticLabel->sizePolicy().hasHeightForWidth());
        locationStaticLabel->setSizePolicy(sizePolicy2);
        locationStaticLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(locationStaticLabel, 1, 0, 1, 1);

        locationLabel = new QLabel(frame_2);
        locationLabel->setObjectName(QString::fromUtf8("locationLabel"));
        sizePolicy2.setHeightForWidth(locationLabel->sizePolicy().hasHeightForWidth());
        locationLabel->setSizePolicy(sizePolicy2);
        locationLabel->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);
        locationLabel->setWordWrap(true);

        gridLayout->addWidget(locationLabel, 1, 1, 1, 1);

        dateStaticLabel = new QLabel(frame_2);
        dateStaticLabel->setObjectName(QString::fromUtf8("dateStaticLabel"));
        sizePolicy2.setHeightForWidth(dateStaticLabel->sizePolicy().hasHeightForWidth());
        dateStaticLabel->setSizePolicy(sizePolicy2);
        dateStaticLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(dateStaticLabel, 2, 0, 1, 1);

        dateLabel = new QLabel(frame_2);
        dateLabel->setObjectName(QString::fromUtf8("dateLabel"));
        sizePolicy2.setHeightForWidth(dateLabel->sizePolicy().hasHeightForWidth());
        dateLabel->setSizePolicy(sizePolicy2);
        dateLabel->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        gridLayout->addWidget(dateLabel, 2, 1, 1, 1);

        roundStaticLabel = new QLabel(frame_2);
        roundStaticLabel->setObjectName(QString::fromUtf8("roundStaticLabel"));
        sizePolicy2.setHeightForWidth(roundStaticLabel->sizePolicy().hasHeightForWidth());
        roundStaticLabel->setSizePolicy(sizePolicy2);
        roundStaticLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(roundStaticLabel, 3, 0, 1, 1);

        roundLabel = new QLabel(frame_2);
        roundLabel->setObjectName(QString::fromUtf8("roundLabel"));
        sizePolicy2.setHeightForWidth(roundLabel->sizePolicy().hasHeightForWidth());
        roundLabel->setSizePolicy(sizePolicy2);
        roundLabel->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        gridLayout->addWidget(roundLabel, 3, 1, 1, 1);

        scoreStaticLabel = new QLabel(frame_2);
        scoreStaticLabel->setObjectName(QString::fromUtf8("scoreStaticLabel"));
        sizePolicy2.setHeightForWidth(scoreStaticLabel->sizePolicy().hasHeightForWidth());
        scoreStaticLabel->setSizePolicy(sizePolicy2);
        scoreStaticLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(scoreStaticLabel, 4, 0, 1, 1);

        scoreLabel = new QLabel(frame_2);
        scoreLabel->setObjectName(QString::fromUtf8("scoreLabel"));
        sizePolicy2.setHeightForWidth(scoreLabel->sizePolicy().hasHeightForWidth());
        scoreLabel->setSizePolicy(sizePolicy2);
        scoreLabel->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        gridLayout->addWidget(scoreLabel, 4, 1, 1, 1);

        komiStaticLabel = new QLabel(frame_2);
        komiStaticLabel->setObjectName(QString::fromUtf8("komiStaticLabel"));
        sizePolicy2.setHeightForWidth(komiStaticLabel->sizePolicy().hasHeightForWidth());
        komiStaticLabel->setSizePolicy(sizePolicy2);
        komiStaticLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(komiStaticLabel, 5, 0, 1, 1);

        komiLabel = new QLabel(frame_2);
        komiLabel->setObjectName(QString::fromUtf8("komiLabel"));
        sizePolicy2.setHeightForWidth(komiLabel->sizePolicy().hasHeightForWidth());
        komiLabel->setSizePolicy(sizePolicy2);
        komiLabel->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        gridLayout->addWidget(komiLabel, 5, 1, 1, 1);

        continueStaticLabel = new QLabel(frame_2);
        continueStaticLabel->setObjectName(QString::fromUtf8("continueStaticLabel"));
        sizePolicy2.setHeightForWidth(continueStaticLabel->sizePolicy().hasHeightForWidth());
        continueStaticLabel->setSizePolicy(sizePolicy2);
        continueStaticLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(continueStaticLabel, 7, 0, 1, 1);

        playerLabel = new QLabel(frame_2);
        playerLabel->setObjectName(QString::fromUtf8("playerLabel"));

        gridLayout->addWidget(playerLabel, 9, 1, 1, 1);

        startMoveSpinBox = new KIntSpinBox(frame_2);
        startMoveSpinBox->setObjectName(QString::fromUtf8("startMoveSpinBox"));
        QSizePolicy sizePolicy3(QSizePolicy::Expanding, QSizePolicy::Fixed);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(startMoveSpinBox->sizePolicy().hasHeightForWidth());
        startMoveSpinBox->setSizePolicy(sizePolicy3);
        startMoveSpinBox->setAccelerated(true);
        startMoveSpinBox->setCorrectionMode(QAbstractSpinBox::CorrectToNearestValue);
        startMoveSpinBox->setMinimum(1);
        startMoveSpinBox->setMaximum(9999);

        gridLayout->addWidget(startMoveSpinBox, 7, 1, 1, 1);

        timeStaticLabel = new QLabel(frame_2);
        timeStaticLabel->setObjectName(QString::fromUtf8("timeStaticLabel"));
        sizePolicy2.setHeightForWidth(timeStaticLabel->sizePolicy().hasHeightForWidth());
        timeStaticLabel->setSizePolicy(sizePolicy2);
        timeStaticLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(timeStaticLabel, 6, 0, 1, 1);

        timeLabel = new QLabel(frame_2);
        timeLabel->setObjectName(QString::fromUtf8("timeLabel"));
        sizePolicy2.setHeightForWidth(timeLabel->sizePolicy().hasHeightForWidth());
        timeLabel->setSizePolicy(sizePolicy2);
        timeLabel->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        gridLayout->addWidget(timeLabel, 6, 1, 1, 1);

        verticalSpacer_6 = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Minimum);

        gridLayout->addItem(verticalSpacer_6, 10, 1, 1, 1);


        verticalLayout_3->addWidget(frame_2);

        gameSetupStack->addWidget(loadGamePage);

        verticalLayout_2->addWidget(gameSetupStack);

        verticalSpacer_4 = new QSpacerItem(20, 20, QSizePolicy::Minimum, QSizePolicy::Fixed);

        verticalLayout_2->addItem(verticalSpacer_4);

        gridLayout_4 = new QGridLayout();
        gridLayout_4->setObjectName(QString::fromUtf8("gridLayout_4"));
        horizontalSpacer_2 = new QSpacerItem(0, 20, QSizePolicy::Minimum, QSizePolicy::Minimum);

        gridLayout_4->addItem(horizontalSpacer_2, 4, 0, 1, 1);

        whiteIsComputerCheckBox = new QCheckBox(SetupWidget);
        whiteIsComputerCheckBox->setObjectName(QString::fromUtf8("whiteIsComputerCheckBox"));

        gridLayout_4->addWidget(whiteIsComputerCheckBox, 4, 2, 1, 1);

        whitePlayerStack = new QStackedWidget(SetupWidget);
        whitePlayerStack->setObjectName(QString::fromUtf8("whitePlayerStack"));
        QSizePolicy sizePolicy4(QSizePolicy::Minimum, QSizePolicy::Minimum);
        sizePolicy4.setHorizontalStretch(0);
        sizePolicy4.setVerticalStretch(0);
        sizePolicy4.setHeightForWidth(whitePlayerStack->sizePolicy().hasHeightForWidth());
        whitePlayerStack->setSizePolicy(sizePolicy4);
        whitePlayerStack->setFrameShape(QFrame::NoFrame);
        whiteHumanPage = new QWidget();
        whiteHumanPage->setObjectName(QString::fromUtf8("whiteHumanPage"));
        horizontalLayout_2 = new QHBoxLayout(whiteHumanPage);
        horizontalLayout_2->setObjectName(QString::fromUtf8("horizontalLayout_2"));
        label_6 = new QLabel(whiteHumanPage);
        label_6->setObjectName(QString::fromUtf8("label_6"));

        horizontalLayout_2->addWidget(label_6);

        whitePlayerName = new KLineEdit(whiteHumanPage);
        whitePlayerName->setObjectName(QString::fromUtf8("whitePlayerName"));
        whitePlayerName->setEnabled(true);

        horizontalLayout_2->addWidget(whitePlayerName);

        whitePlayerStack->addWidget(whiteHumanPage);
        whiteComputerPage = new QWidget();
        whiteComputerPage->setObjectName(QString::fromUtf8("whiteComputerPage"));
        gridLayout_8 = new QGridLayout(whiteComputerPage);
        gridLayout_8->setContentsMargins(0, 0, 0, 0);
        gridLayout_8->setObjectName(QString::fromUtf8("gridLayout_8"));
        label1 = new QLabel(whiteComputerPage);
        label1->setObjectName(QString::fromUtf8("label1"));
        QSizePolicy sizePolicy5(QSizePolicy::Fixed, QSizePolicy::Preferred);
        sizePolicy5.setHorizontalStretch(0);
        sizePolicy5.setVerticalStretch(0);
        sizePolicy5.setHeightForWidth(label1->sizePolicy().hasHeightForWidth());
        label1->setSizePolicy(sizePolicy5);
        label1->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_8->addWidget(label1, 0, 0, 1, 1);

        label2 = new QLabel(whiteComputerPage);
        label2->setObjectName(QString::fromUtf8("label2"));
        sizePolicy5.setHeightForWidth(label2->sizePolicy().hasHeightForWidth());
        label2->setSizePolicy(sizePolicy5);
        label2->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        gridLayout_8->addWidget(label2, 0, 3, 1, 1);

        whiteStrengthSlider = new QSlider(whiteComputerPage);
        whiteStrengthSlider->setObjectName(QString::fromUtf8("whiteStrengthSlider"));
        whiteStrengthSlider->setMinimum(1);
        whiteStrengthSlider->setMaximum(10);
        whiteStrengthSlider->setPageStep(1);
        whiteStrengthSlider->setValue(5);
        whiteStrengthSlider->setOrientation(Qt::Horizontal);
        whiteStrengthSlider->setTickPosition(QSlider::TicksBelow);
        whiteStrengthSlider->setTickInterval(0);

        gridLayout_8->addWidget(whiteStrengthSlider, 0, 1, 1, 1);

        whitePlayerStack->addWidget(whiteComputerPage);

        gridLayout_4->addWidget(whitePlayerStack, 5, 2, 2, 1);

        verticalSpacer_2 = new QSpacerItem(20, 20, QSizePolicy::Minimum, QSizePolicy::Fixed);

        gridLayout_4->addItem(verticalSpacer_2, 7, 2, 1, 1);

        blackStoneImageLabel = new QLabel(SetupWidget);
        blackStoneImageLabel->setObjectName(QString::fromUtf8("blackStoneImageLabel"));
        QSizePolicy sizePolicy6(QSizePolicy::Fixed, QSizePolicy::Fixed);
        sizePolicy6.setHorizontalStretch(0);
        sizePolicy6.setVerticalStretch(0);
        sizePolicy6.setHeightForWidth(blackStoneImageLabel->sizePolicy().hasHeightForWidth());
        blackStoneImageLabel->setSizePolicy(sizePolicy6);
        blackStoneImageLabel->setMinimumSize(QSize(48, 48));
        blackStoneImageLabel->setMaximumSize(QSize(48, 48));
        blackStoneImageLabel->setFrameShape(QFrame::NoFrame);

        gridLayout_4->addWidget(blackStoneImageLabel, 8, 1, 3, 1);

        blackIsComputerCheckBox = new QCheckBox(SetupWidget);
        blackIsComputerCheckBox->setObjectName(QString::fromUtf8("blackIsComputerCheckBox"));

        gridLayout_4->addWidget(blackIsComputerCheckBox, 9, 2, 1, 1);

        blackPlayerStack = new QStackedWidget(SetupWidget);
        blackPlayerStack->setObjectName(QString::fromUtf8("blackPlayerStack"));
        sizePolicy2.setHeightForWidth(blackPlayerStack->sizePolicy().hasHeightForWidth());
        blackPlayerStack->setSizePolicy(sizePolicy2);
        blackHumanPage = new QWidget();
        blackHumanPage->setObjectName(QString::fromUtf8("blackHumanPage"));
        horizontalLayout_3 = new QHBoxLayout(blackHumanPage);
        horizontalLayout_3->setObjectName(QString::fromUtf8("horizontalLayout_3"));
        label_7 = new QLabel(blackHumanPage);
        label_7->setObjectName(QString::fromUtf8("label_7"));

        horizontalLayout_3->addWidget(label_7);

        blackPlayerName = new KLineEdit(blackHumanPage);
        blackPlayerName->setObjectName(QString::fromUtf8("blackPlayerName"));
        blackPlayerName->setEnabled(true);

        horizontalLayout_3->addWidget(blackPlayerName);

        blackPlayerStack->addWidget(blackHumanPage);
        blackComputerPage = new QWidget();
        blackComputerPage->setObjectName(QString::fromUtf8("blackComputerPage"));
        gridLayout_3 = new QGridLayout(blackComputerPage);
        gridLayout_3->setContentsMargins(0, 0, 0, 0);
        gridLayout_3->setObjectName(QString::fromUtf8("gridLayout_3"));
        label2_3 = new QLabel(blackComputerPage);
        label2_3->setObjectName(QString::fromUtf8("label2_3"));
        sizePolicy5.setHeightForWidth(label2_3->sizePolicy().hasHeightForWidth());
        label2_3->setSizePolicy(sizePolicy5);
        label2_3->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        gridLayout_3->addWidget(label2_3, 0, 4, 1, 1);

        label1_3 = new QLabel(blackComputerPage);
        label1_3->setObjectName(QString::fromUtf8("label1_3"));
        sizePolicy5.setHeightForWidth(label1_3->sizePolicy().hasHeightForWidth());
        label1_3->setSizePolicy(sizePolicy5);
        label1_3->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_3->addWidget(label1_3, 0, 2, 1, 1);

        blackStrengthSlider = new QSlider(blackComputerPage);
        blackStrengthSlider->setObjectName(QString::fromUtf8("blackStrengthSlider"));
        blackStrengthSlider->setMinimum(1);
        blackStrengthSlider->setMaximum(10);
        blackStrengthSlider->setPageStep(1);
        blackStrengthSlider->setValue(5);
        blackStrengthSlider->setOrientation(Qt::Horizontal);
        blackStrengthSlider->setTickPosition(QSlider::TicksBelow);
        blackStrengthSlider->setTickInterval(0);

        gridLayout_3->addWidget(blackStrengthSlider, 0, 3, 1, 1);

        blackPlayerStack->addWidget(blackComputerPage);

        gridLayout_4->addWidget(blackPlayerStack, 10, 2, 2, 1);

        verticalSpacer_3 = new QSpacerItem(20, 20, QSizePolicy::Minimum, QSizePolicy::Fixed);

        gridLayout_4->addItem(verticalSpacer_3, 12, 2, 1, 1);

        verticalSpacer_7 = new QSpacerItem(20, 0, QSizePolicy::Minimum, QSizePolicy::Minimum);

        gridLayout_4->addItem(verticalSpacer_7, 6, 1, 1, 1);

        verticalSpacer_8 = new QSpacerItem(20, 0, QSizePolicy::Minimum, QSizePolicy::Minimum);

        gridLayout_4->addItem(verticalSpacer_8, 11, 1, 1, 1);

        verticalSpacer_9 = new QSpacerItem(20, 4, QSizePolicy::Minimum, QSizePolicy::Fixed);

        gridLayout_4->addItem(verticalSpacer_9, 3, 2, 1, 1);

        whiteStoneImageLabel = new QLabel(SetupWidget);
        whiteStoneImageLabel->setObjectName(QString::fromUtf8("whiteStoneImageLabel"));
        QSizePolicy sizePolicy7(QSizePolicy::Fixed, QSizePolicy::MinimumExpanding);
        sizePolicy7.setHorizontalStretch(0);
        sizePolicy7.setVerticalStretch(0);
        sizePolicy7.setHeightForWidth(whiteStoneImageLabel->sizePolicy().hasHeightForWidth());
        whiteStoneImageLabel->setSizePolicy(sizePolicy7);
        whiteStoneImageLabel->setMinimumSize(QSize(48, 48));
        whiteStoneImageLabel->setMaximumSize(QSize(48, 48));
        whiteStoneImageLabel->setFrameShape(QFrame::NoFrame);

        gridLayout_4->addWidget(whiteStoneImageLabel, 3, 1, 3, 1);

        verticalSpacer_10 = new QSpacerItem(20, 4, QSizePolicy::Minimum, QSizePolicy::Fixed);

        gridLayout_4->addItem(verticalSpacer_10, 8, 2, 1, 1);


        verticalLayout_2->addLayout(gridLayout_4);

        verticalSpacer = new QSpacerItem(20, 10, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout_2->addItem(verticalSpacer);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QString::fromUtf8("horizontalLayout"));
        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        startButton = new KPushButton(SetupWidget);
        startButton->setObjectName(QString::fromUtf8("startButton"));

        horizontalLayout->addWidget(startButton);


        verticalLayout_2->addLayout(horizontalLayout);

        gameSetupStack->raise();
#ifndef UI_QT_NO_SHORTCUT
        label_5->setBuddy(handicapSpinBox);
        label_4->setBuddy(komiSpinBox);
        continueStaticLabel->setBuddy(startMoveSpinBox);
        label_6->setBuddy(whitePlayerName);
        label1->setBuddy(whiteStrengthSlider);
        label2->setBuddy(whiteStrengthSlider);
        label_7->setBuddy(blackPlayerName);
        label2_3->setBuddy(blackStrengthSlider);
        label1_3->setBuddy(blackStrengthSlider);
#endif // QT_NO_SHORTCUT
        QWidget::setTabOrder(whitePlayerName, whiteStrengthSlider);
        QWidget::setTabOrder(whiteStrengthSlider, blackPlayerName);
        QWidget::setTabOrder(blackPlayerName, blackStrengthSlider);

        retranslateUi(SetupWidget);

        gameSetupStack->setCurrentIndex(0);
        whitePlayerStack->setCurrentIndex(0);
        blackPlayerStack->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(SetupWidget);
    } // setupUi

    void retranslateUi(QWidget *SetupWidget)
    {
        label_12->setText(tr2i18n("Board size:", 0));
        sizeSmall->setText(tr2i18n("Tiny (9x9)", 0));
        sizeMedium->setText(tr2i18n("Small (13x13)", 0));
        sizeBig->setText(tr2i18n("Normal (19x19)", 0));
        sizeOther->setText(tr2i18n("Custom:", 0));
        label_5->setText(tr2i18n("Handicap:", 0));
#ifndef UI_QT_NO_TOOLTIP
        handicapSpinBox->setToolTip(tr2i18n("Handicap stones are an advantage for the black player.\n"
"Black gets a number of stones on the board before the game starts.", 0));
#endif // QT_NO_TOOLTIP
        handicapSpinBox->setSpecialValueText(tr2i18n("No handicap", 0));
        handicapSpinBox->setSuffix(tr2i18n(" Stones", 0));
        label_4->setText(tr2i18n("Komi:", 0));
#ifndef UI_QT_NO_TOOLTIP
        komiSpinBox->setToolTip(tr2i18n("Komi are points given to the white player at the end of the game.\n"
"It balances out the advantage black has by making the first move.", 0));
#endif // QT_NO_TOOLTIP
        komiSpinBox->setSuffix(tr2i18n(" Points", 0));
        eventStaticLabel->setText(tr2i18n("Event:", 0));
        eventLabel->setText(QString());
        locationStaticLabel->setText(tr2i18n("Location:", 0));
        locationLabel->setText(QString());
        dateStaticLabel->setText(tr2i18n("Date:", 0));
        dateLabel->setText(QString());
        roundStaticLabel->setText(tr2i18n("Round:", 0));
        roundLabel->setText(QString());
        scoreStaticLabel->setText(tr2i18n("Score:", 0));
        scoreLabel->setText(QString());
        komiStaticLabel->setText(tr2i18n("Komi:", 0));
        komiLabel->setText(QString());
        continueStaticLabel->setText(tr2i18n("Continue:", 0));
        playerLabel->setText(tr2i18n("Black to play", 0));
        startMoveSpinBox->setSuffix(tr2i18n(" of 999", 0));
        startMoveSpinBox->setPrefix(tr2i18n("Move ", 0));
        timeStaticLabel->setText(tr2i18n("Time limit:", 0));
        timeLabel->setText(QString());
        whiteIsComputerCheckBox->setText(tr2i18n("&Computer", 0));
        label_6->setText(tr2i18n("Name:", 0));
        whitePlayerName->setText(QString());
        label1->setText(tr2i18n("Weak", 0));
        label2->setText(tr2i18n("Strong", 0));
        blackStoneImageLabel->setText(QString());
        blackIsComputerCheckBox->setText(tr2i18n("C&omputer", 0));
        label_7->setText(tr2i18n("Name:", 0));
        blackPlayerName->setText(QString());
        label2_3->setText(tr2i18n("Strong", 0));
        label1_3->setText(tr2i18n("Weak", 0));
        whiteStoneImageLabel->setText(QString());
        startButton->setText(tr2i18n("Start Game", 0));
        Q_UNUSED(SetupWidget);
    } // retranslateUi

};

namespace Ui {
    class SetupWidget: public Ui_SetupWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SETUPWIDGET_H

